==> jc-1.4.0.tar.gz: java/awt/geom/Ellipse2D.h <==
// public abstract class java.awt.geom.Ellipse2D

// class file dependencies
// @dep_class 718dd7c671fd5bb1 java_awt_geom_Ellipse2D
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_RectangularShape

#include "java/awt/geom/RectangularShape.h"

#ifndef _JC_java_awt_geom_Ellipse2D_H_
#define _JC_java_awt_geom_Ellipse2D_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_PathIterator$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Ellipse2D$sub_refs	_jc_java_awt_geom_Ellipse2D$sub_refs;
typedef struct _jc_java_awt_geom_Ellipse2D$sub_nonrefs	_jc_java_awt_geom_Ellipse2D$sub_nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D$refs	_jc_java_awt_geom_Ellipse2D$refs;
typedef struct _jc_java_awt_geom_Ellipse2D$nonrefs	_jc_java_awt_geom_Ellipse2D$nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D$object	_jc_java_awt_geom_Ellipse2D$object;

typedef const struct _jc_java_awt_geom_Ellipse2D$vmethods	_jc_java_awt_geom_Ellipse2D$vmethods;
typedef const struct _jc_java_awt_geom_Ellipse2D$vtable	_jc_java_awt_geom_Ellipse2D$vtable;
typedef const struct _jc_java_awt_geom_Ellipse2D$vtype	_jc_java_awt_geom_Ellipse2D$vtype;

// Constructors
extern void _jc_java_awt_geom_Ellipse2D$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *);

// Virtual methods
extern jboolean _jc_java_awt_geom_Ellipse2D$method$contains$1fcb7af0670d90da(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble);
extern jboolean _jc_java_awt_geom_Ellipse2D$method$contains$376a5256b83f326c(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble);
extern struct _jc_object *_jc_java_awt_geom_Ellipse2D$method$getPathIterator$3845b8ac383ab152(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, struct _jc_java_awt_geom_AffineTransform$object *);
extern jboolean _jc_java_awt_geom_Ellipse2D$method$intersects$2b8e6b0338473a03(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$contains$1fcb7af0670d90da;
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$contains$376a5256b83f326c;
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$getPathIterator$3845b8ac383ab152;
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$intersects$2b8e6b0338473a03;

// Virtual methods structure
struct _jc_java_awt_geom_Ellipse2D$vmethods {
	jboolean	(*contains$1fcb7af0670d90da)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble);
	jboolean	(*contains$376a5256b83f326c)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble);
	struct _jc_object	*(*getPathIterator$3845b8ac383ab152)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, struct _jc_java_awt_geom_AffineTransform$object *);
	jboolean	(*intersects$2b8e6b0338473a03)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble);
};

// Vtable
struct _jc_java_awt_geom_Ellipse2D$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Ellipse2D$vmethods	java_awt_geom_Ellipse2D;
};

// Vtype
struct _jc_java_awt_geom_Ellipse2D$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Ellipse2D$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D$refs {
    _jc_java_awt_geom_Ellipse2D$sub_refs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Ellipse2D$sub_nonrefs	java_awt_geom_Ellipse2D;
};

// Object instance structure
struct _jc_java_awt_geom_Ellipse2D$object {
	_jc_java_awt_geom_Ellipse2D$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Ellipse2D$vtype	*vtype;
	_jc_java_awt_geom_Ellipse2D$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Ellipse2D$vtype _jc_java_awt_geom_Ellipse2D$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Ellipse2D, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Ellipse2D$class_object;

#endif	/* _JC_java_awt_geom_Ellipse2D_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Ellipse2D.h <==
// public abstract class java.awt.geom.Ellipse2D

// class file dependencies
// @dep_class 718dd7c671fd5bb1 java_awt_geom_Ellipse2D
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_RectangularShape

#include "java/awt/geom/RectangularShape.h"

#ifndef _JC_java_awt_geom_Ellipse2D_H_
#define _JC_java_awt_geom_Ellipse2D_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_PathIterator$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Ellipse2D$sub_refs	_jc_java_awt_geom_Ellipse2D$sub_refs;
typedef struct _jc_java_awt_geom_Ellipse2D$sub_nonrefs	_jc_java_awt_geom_Ellipse2D$sub_nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D$refs	_jc_java_awt_geom_Ellipse2D$refs;
typedef struct _jc_java_awt_geom_Ellipse2D$nonrefs	_jc_java_awt_geom_Ellipse2D$nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D$object	_jc_java_awt_geom_Ellipse2D$object;

typedef const struct _jc_java_awt_geom_Ellipse2D$vmethods	_jc_java_awt_geom_Ellipse2D$vmethods;
typedef const struct _jc_java_awt_geom_Ellipse2D$vtable	_jc_java_awt_geom_Ellipse2D$vtable;
typedef const struct _jc_java_awt_geom_Ellipse2D$vtype	_jc_java_awt_geom_Ellipse2D$vtype;

// Constructors
extern void _jc_java_awt_geom_Ellipse2D$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_geom_Ellipse2D$method$contains$1fcb7af0670d90da(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_Ellipse2D$method$contains$376a5256b83f326c(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_geom_Ellipse2D$method$getPathIterator$3845b8ac383ab152(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_Ellipse2D$method$intersects$2b8e6b0338473a03(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$contains$1fcb7af0670d90da;
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$contains$376a5256b83f326c;
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$getPathIterator$3845b8ac383ab152;
extern _jc_method _jc_java_awt_geom_Ellipse2D$method_info$intersects$2b8e6b0338473a03;

// Virtual methods structure
struct _jc_java_awt_geom_Ellipse2D$vmethods {
	jboolean	(*contains$1fcb7af0670d90da)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble) _JC_JCNI_ATTR;
	jboolean	(*contains$376a5256b83f326c)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPathIterator$3845b8ac383ab152)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;
	jboolean	(*intersects$2b8e6b0338473a03)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Ellipse2D$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Ellipse2D$vmethods	java_awt_geom_Ellipse2D;
};

// Vtype
struct _jc_java_awt_geom_Ellipse2D$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Ellipse2D$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D$refs {
    _jc_java_awt_geom_Ellipse2D$sub_refs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Ellipse2D$sub_nonrefs	java_awt_geom_Ellipse2D;
};

// Object instance structure
struct _jc_java_awt_geom_Ellipse2D$object {
	_jc_java_awt_geom_Ellipse2D$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Ellipse2D$vtype	*vtype;
	_jc_java_awt_geom_Ellipse2D$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Ellipse2D$vtype _jc_java_awt_geom_Ellipse2D$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Ellipse2D, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Ellipse2D$class_object;

#endif	/* _JC_java_awt_geom_Ellipse2D_H_ */
